@@ -378,7 +378,8 @@ class PerturbFlow(nn.Module):
 
     def guide1(self, xs):
         with pyro.plate('data'):
-            zn_loc, zn_scale = self.encoder_zn(xs)
+            #zn_loc, zn_scale = self.encoder_zn(xs)
+            zn_loc, zn_scale = self._get_basal_embedding(xs)
             zns = pyro.sample('zn', dist.Normal(zn_loc, zn_scale).to_event(1))
 
             alpha = self.encoder_n(zns)
@@ -466,7 +467,8 @@ class PerturbFlow(nn.Module):
 
     def guide2(self, xs, us=None):
         with pyro.plate('data'):
-            zn_loc, zn_scale = self.encoder_zn(xs)
+            #zn_loc, zn_scale = self.encoder_zn(xs)
+            zn_loc, zn_scale = self._get_basal_embedding(xs)
             zns = pyro.sample('zn', dist.Normal(zn_loc, zn_scale).to_event(1))
 
             alpha = self.encoder_n(zns)
@@ -561,7 +563,8 @@ class PerturbFlow(nn.Module):
     def guide3(self, xs, ys, embeds=None):
         with pyro.plate('data'):
             if embeds is None:
-                zn_loc, zn_scale = self.encoder_zn(xs)
+                #zn_loc, zn_scale = self.encoder_zn(xs)
+                zn_loc, zn_scale = self._get_basal_embedding(xs)
                 zns = pyro.sample('zn', dist.Normal(zn_loc, zn_scale).to_event(1))
 
     def model4(self, xs, us, ys, embeds=None):
@@ -663,7 +666,8 @@ class PerturbFlow(nn.Module):
     def guide4(self, xs, us, ys, embeds=None):
         with pyro.plate('data'):
             if embeds is None:
-                zn_loc, zn_scale = self.encoder_zn(xs)
+                #zn_loc, zn_scale = self.encoder_zn(xs)
+                zn_loc, zn_scale = self._get_basal_embedding(xs)
                 zns = pyro.sample('zn', dist.Normal(zn_loc, zn_scale).to_event(1))
 
     def _total_effects(self, zns, us):
@@ -692,8 +696,8 @@ class PerturbFlow(nn.Module):
         return cb
 
     def _get_basal_embedding(self, xs):           
-        zns, _ = self.encoder_zn(xs)
-        return zns 
+        loc, scale = self.encoder_zn(xs)
+        return loc, scale 
     
     def get_basal_embedding(self, 
                              xs, 
@@ -720,7 +724,7 @@ class PerturbFlow(nn.Module):
         Z = []
         with tqdm(total=len(dataloader), desc='', unit='batch') as pbar:
             for X_batch, _ in dataloader:
-                zns = self._get_basal_embedding(X_batch)
+                zns,_ = self._get_basal_embedding(X_batch)
                 Z.append(tensor_to_numpy(zns))
                 pbar.update(1)
 
@@ -732,7 +736,7 @@ class PerturbFlow(nn.Module):
             alpha = self.encoder_n(xs)
         else:
             #zns,_ = self.encoder_zn(xs)
-            zns = self._get_basal_embedding(xs)
+            zns,_ = self._get_basal_embedding(xs)
             alpha = self.encoder_n(zns)
         return alpha
     
@@ -803,7 +807,7 @@ class PerturbFlow(nn.Module):
     
     def _cell_response(self, xs, factor_idx, perturb):
         #zns,_ = self.encoder_zn(xs)    
-        zns = self._get_basal_embedding(xs)   
+        zns,_ = self._get_basal_embedding(xs)   
         if perturb.ndim==2:
             ms = self.cell_factor_effect[factor_idx]([zns, perturb])
         else:
@@ -893,7 +897,7 @@ class PerturbFlow(nn.Module):
         E = []
         with tqdm(total=len(dataloader), desc='', unit='batch') as pbar:
             for Z_batch, _ in dataloader:
-                concentrate = self._expression(Z_batch)
+                concentrate = self._get_expression_response(Z_batch)
                 if use_sampler:
                     counts = self._count_sample(concentrate)
                 else:
